summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2022-02-08 14:02:27 +0100
committerChristian Grothoff <christian@grothoff.org>2022-02-08 14:02:27 +0100
commitb3cf788424d641fb945fe4c9abe29155a6c6e962 (patch)
tree1a2c6b637dde250f5cbceefa6581cdb4e8dcea61 /src/include
parent8cbe16a2203d581ad2bdfcd7240653d1ee416634 (diff)
downloadexchange-b3cf788424d641fb945fe4c9abe29155a6c6e962.tar.gz
exchange-b3cf788424d641fb945fe4c9abe29155a6c6e962.tar.bz2
exchange-b3cf788424d641fb945fe4c9abe29155a6c6e962.zip
-more test fixes
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_exchange_service.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 65b8d72b6..a65e796a5 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -1705,9 +1705,9 @@ TALER_EXCHANGE_melt_cancel (struct TALER_EXCHANGE_MeltHandle *mh);
*
* @param cls closure
* @param hr HTTP response data
* @param num_coins number of fresh coins created, length of the @a sigs and @a coin_privs arrays, 0 if the operation failed
* @param exchange_vals array of contributions from the exchange on the refreshes
* @param coin_privs array of @a num_coins private keys for the coins that were created, NULL on error
+ * @param psa array of @a num_coins planchet secrets (derived from the transfer secret) for each of the coins
* @param sigs array of signature over @a num_coins coins, NULL on error
*/
typedef void
@@ -1716,6 +1716,7 @@ typedef void
const struct TALER_EXCHANGE_HttpResponse *hr,
unsigned int num_coins,
const struct TALER_CoinSpendPrivateKeyP *coin_privs,
+ const struct TALER_PlanchetSecretsP *psa,
const struct TALER_DenominationSignature *sigs);
@@ -1705,9 +1705,9 @@ TALER_EXCHANGE_melt_cancel (struct TALER_EXCHANGE_MeltHandle *mh);
* @param cls closure
* @param hr HTTP response data
- * @param num_coins number of fresh coins created, length of the @a sigs and @a coin_privs arrays, 0 if the operation failed
- * @param exchange_vals array of contributions from the exchange on the refreshes
+ * @param num_coins number of fresh coins created, length of the @a sigs, @a psa and @a coin_privs arrays, 0 if the operation failed
* @param coin_privs array of @a num_coins private keys for the coins that were created, NULL on error